"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const index_1 = require("../dist/index");
const chai_1 = require("chai");
const nanStr = '"\\u001bNaN"';
const infStr = '"\\u001bInf"';
const ninfStr = '"\\u001b-Inf"';
const undefinedStr = '"\\u001b"';
describe('esc', () => {
    it('numbers', () => {
        chai_1.assert.isNaN(index_1.default.parse(nanStr), 'decode NaN');
        chai_1.assert.equal(index_1.default.parse(infStr), Infinity, 'decode Infinity');
        chai_1.assert.equal(index_1.default.parse(ninfStr), -Infinity, 'decode -Infinity');
        chai_1.assert.equal(index_1.default.parse('1.25'), 1.25, 'decode normal value');
        chai_1.assert.equal(index_1.default.stringify(NaN), nanStr, 'encode NaN');
        chai_1.assert.equal(index_1.default.stringify(Infinity), infStr, 'encode Infinity');
        chai_1.assert.equal(index_1.default.stringify(-Infinity), ninfStr, 'encode -Infinity');
        chai_1.assert.equal(index_1.default.stringify(1.25), '1.25', 'encode normal number');
    });
    it('Date', () => {
        {
            let date = new Date(1518030438207);
            let dateStr = '"\\u001bDate:2018-02-07T19:07:18.207Z"';
            chai_1.assert.equal(index_1.default.stringify(date), dateStr, 'encode date');
            chai_1.assert.equal(index_1.default.parse(dateStr).getTime(), 1518030438207, 'decode date');
        }
        {
            let date = new Date(-1);
            let dateStr = '"\\u001bDate:1969-12-31T23:59:59.999Z"';
            chai_1.assert.equal(index_1.default.stringify(date), dateStr, 'encode date before 1970');
            chai_1.assert.equal(index_1.default.parse(dateStr).getTime(), -1, 'decode date before 1970');
        }
    });
    it('Uint8Array Base93', () => {
        let bin = new Uint8Array([91, 82, 112, 207]);
        let binStr = "\"\\u001bBin:xy'/z\"";
        chai_1.assert.equal(index_1.default.stringify(bin), binStr, 'encode Uint8Array Base64');
        chai_1.assert.deepEqual(index_1.default.parse(binStr), bin, 'decode Uint8Array Base64');
    });
    it('object toJsonEsc', () => {
        class A {
            toJsonEsc() {
                return '\u001bA';
            }
        }
        chai_1.assert.equal(index_1.default.stringify(new A()), '"\\u001bA"');
    });
    it('function toJsonEsc', () => {
        function F() {
        }
        F.toJsonEsc = () => {
            return '\u001bF';
        };
        chai_1.assert.equal(index_1.default.stringify(F), '"\\u001bF"');
    });
    it('undefined', () => {
        chai_1.assert.equal(index_1.default.stringify(undefined), '"\\u001b"', 'encode undefined');
        chai_1.assert.equal(index_1.default.stringify({ a: undefined }), `{}`, 'encode undefined in object');
        chai_1.assert.equal(index_1.default.stringify([undefined]), `["\\u001b"]`, 'encode undefined in array');
        let encoder = new index_1.default();
        chai_1.assert.equal(encoder.stringifySorted(undefined), '"\\u001b"', 'encode undefined');
        chai_1.assert.equal(encoder.stringifySorted({ a: undefined }), `{}`, 'encode undefined in object');
        chai_1.assert.equal(encoder.stringifySorted([undefined]), `["\\u001b"]`, 'encode undefined in array');
        chai_1.assert.equal(index_1.default.parse('"\\u001b"'), undefined, 'undefined');
        chai_1.assert.equal(index_1.default.parse('"\\u001b?"'), undefined, 'invalid escape');
        chai_1.assert.deepEqual(index_1.default.parse('["\\u001b",1]'), [undefined, 1]);
    });
});
describe('sorted', () => {
    it('basic', () => {
        chai_1.assert.equal(index_1.default.stringify(NaN, undefined, true), nanStr, 'encode NaN');
        chai_1.assert.equal(index_1.default.stringify(1, undefined, true), '1', 'encode 1');
        chai_1.assert.equal(index_1.default.stringify("", undefined, true), '""', 'encode string');
        chai_1.assert.equal(index_1.default.stringify({}, undefined, true), '{}', 'blank Object');
        chai_1.assert.equal(index_1.default.stringify([], undefined, true), '[]', 'blank array');
        chai_1.assert.equal(index_1.default.stringify({ c: 1, a: 2, b: 3 }, undefined, true), '{"a":2,"b":3,"c":1}');
        chai_1.assert.equal(index_1.default.stringify({ c: 1, a: 2, b: 3 }, 1, true), `{
"a": 2,
"b": 3,
"c": 1
}`);
    });
});
//# sourceMappingURL=test-esc.js.map